@@ -1,16 +1,16 @@
 /*
     This file is part of KDE.
 
-    SPDX-FileCopyrightText: 2019-2020 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2019-2021 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 #include <QApplication>
-#include <QWidget>
 #include <QVBoxLayout>
+#include <QWidget>
 
-#include "textutils.h"
 #include "emoticon/emoticonunicodetab.h"
+#include "textutils.h"
 
 class Window : public QWidget
 {
@@ -19,8 +19,8 @@ public:
     explicit Window(QWidget *parent = nullptr)
         : QWidget(parent)
     {
-        auto *mainLayout = new QVBoxLayout(this);
-        auto *w = new KPIMTextEdit::EmoticonUnicodeTab(this);
+        auto mainLayout = new QVBoxLayout(this);
+        auto w = new KPIMTextEdit::EmoticonUnicodeTab(this);
         mainLayout->addWidget(w);
     }
 };
